# mypackage

--------------------------------------------------------------------------------

![Test Status](https://github.com/seba-1511/mypackage/workflows/Testing/badge.svg?branch=master)

Template to start new PyPI packages

To get started, grep and replace for `mypackage` everywhere.
